pub struct DisplayDriver { /* private fields */ }Expand description
An embedded-graphics draw target for the V5 Brain display
Currently, this does not support touch detection like the regular Display API.
Implementations
Sourceimpl DisplayDriver
impl DisplayDriver
Sourcepub fn new(display: Display) -> Self
pub fn new(display: Display) -> Self
Create a new DisplayDriver from a Display.
The display peripheral must be moved into this struct, as it is used to render the display and having multiple mutable references to it is unsafe.
Sourcepub fn touch_status(&self) -> TouchEvent
pub fn touch_status(&self) -> TouchEvent
Returns the current touch status of the display.